Currently, the CDF (cdf) is required to be specified, along with the PMF
(pmf) for discrete distributions and density (density) for continuous
distributions. Otherwise, the full extent of distribution properties will
not be accessible.
A distributional representation is a function that fully describes the
distribution. Besides cdf, density, and pmf, other options
understood by distionary include:
survival: the survival function, or one minus the cdf.
hazard: the hazard function, for continuous variables only.
chf: the cumulative hazard function, for continuous variables only.
quantile: the quantile function, or left-inverse of the cdf.
realise or realize: a function that takes an integer and generates
a vector of that many random draws from the distribution.
odds: for discrete variables, the probability odds function
(pmf / (1 - pmf))
return: the quantiles associated with the provided return periods,
where events are exceedances.
All functions should be vectorized.
Other properties that are understood by distionary include:
mean, stdev, variance, skewness, median are self-explanatory.
kurtosis_exc and kurtosis are the distribution's excess
kurtosis and regular kurtosis.
range: A vector of the minimum and maximum value of a distribution's
support.