Learn R Programming

distionary (version 0.1.0)

dst_geom: Geometric Distribution

Description

Makes a Geometric distribution, corresponding to the number of failures in a sequence of independent trials before observing a success.

Usage

dst_geom(prob)

Value

A Geometric distribution.

Arguments

prob

Probability of success in each trial; single numeric between 0 and 1.

Examples

Run this code
d <- dst_geom(0.4)

# This version of the Geometric distribution does not count the success.
range(d)

Run the code above in your browser using DataLab