Learn R Programming

distionary (version 0.1.0)

dst_gev: Generalised Extreme Value Distribution

Description

Makes a Generalised Extreme Value (GEV) distribution, which is the limiting distribution of the maximum.

Usage

dst_gev(location, scale, shape)

Value

A GEV distribution.

Arguments

location

Location parameter; single numeric.

scale

Scale parameter; single positive numeric.

shape

Shape parameter; single numeric. This is also the extreme value index, so that shape > 0 is heavy tailed, and shape < 0 is short-tailed.

Examples

Run this code
# Short-tailed example
short <- dst_gev(0, 1, -1)
range(short)
mean(short)

# Heavy-tailed example
heavy <- dst_gev(0, 1, 1)
range(heavy)
mean(heavy)

# Light-tailed example (a Gumbel distribution)
light <- dst_gev(0, 1, 0)
range(light)
mean(light)

Run the code above in your browser using DataLab