Learn R Programming

distionary (version 0.1.0)

dst_lnorm: Log Normal Distribution

Description

Makes a Log Normal distribution, which is the distribution of the exponential of a Normally distributed random variable.

Usage

dst_lnorm(meanlog, sdlog)

Value

A Log Normal distribution.

Arguments

meanlog

Mean of the log of the random variable; single numeric.

sdlog

Standard deviation of the log of the random variable; single positive numeric.

Examples

Run this code
dst_lnorm(0, 1)

Run the code above in your browser using DataLab