Learn R Programming

distionary (version 0.1.0)

dst_lp3: Log Pearson Type III distribution

Description

Makes a Log Pearson Type III distribution, which is the distribution of the exponential of a random variable following a Pearson Type III distribution.

Usage

dst_lp3(meanlog, sdlog, skew)

Value

A Log Pearson Type III distribution.

Arguments

meanlog

Mean of the log of the random variable; single numeric.

sdlog

Standard deviation of the log of the random variable; single positive numeric.

skew

Skewness of the log of the random variable; single numeric.

Examples

Run this code
dst_lp3(0, 1, 1)

Run the code above in your browser using DataLab