Learn R Programming

distionary (version 0.1.0)

dst_pearson3: Pearson Type III distribution

Description

Makes a Pearson Type III distribution, which is a Gamma distribution, but shifted.

Usage

dst_pearson3(location, scale, shape)

Value

A Pearson Type III distribution.

Arguments

location

Location parameter, specifying how to shift the Gamma distribution; single numeric.

scale

Scale parameter of the Gamma distribution; single positive numeric.

shape

Shape parameter of the Gamma distribution; single positive numeric.

Examples

Run this code
dst_pearson3(1, 1, 1)

Run the code above in your browser using DataLab