Learn R Programming

distionary (version 0.1.0)

kurtosis: Moments of a Distribution

Description

Get common moment-related quantities of a distribution: mean, variance, standard deviation (stdev), skewness, and kurtosis or excess kurtosis (kurtosis_exc). If these quantities are not supplied in the distribution's definition, a numerical algorithm may be used.

Usage

kurtosis(distribution)

kurtosis_exc(distribution)

# S3 method for dst mean(x, ...)

skewness(distribution)

stdev(distribution)

variance(distribution)

Value

A single numeric.

Arguments

x, distribution

Distribution to evaluate.

...

When calculating the mean via integration of the quantile function, arguments passed to stats::integrate().

Details

If there is no method associated with a subclass of x, then moments are calculated using stats::integrate() from the density function.

Examples

Run this code
a <- dst_gp(1, 0.5)
b <- dst_unif(0, 1)
c <- dst_norm(3, 4)
mean(a)
variance(b)
kurtosis(c)
kurtosis_exc(c)

Run the code above in your browser using DataLab