Learn R Programming

distionary (version 0.1.0)

pgev: Representations of the Generalized Extreme Value Distribution

Description

Representations of the Generalized Extreme Value Distribution

Usage

pgev(q, location, scale, shape)

qgev(p, location, scale, shape)

dgev(x, location, scale, shape)

Value

Vector of evaluated GEV distribution, with length equal to the recycled lengths of q/x/p, location, scale, and shape.

Arguments

location

Location parameter; numeric vector.

scale

Scale parameter; positive numeric vector.

shape

Shape parameter; numeric vector. This is also the extreme value index, so that shape > 0 is heavy tailed, and shape < 0 is short-tailed.

p

Vector of probabilities.

x, q

Vector of quantiles.

Examples

Run this code
pgev(1:10, 0, 1, 1)
dgev(1:10, 1:10, 2, 0)
qgev(1:9 / 10, 2, 10, -2)

Run the code above in your browser using DataLab