powered by
Print the name of a distribution, possibly with parameters.
pretty_name(distribution, param_digits = 0)
A character containing the distribution's name, possibly followed by parameters in brackets.
Distribution object.
How many significant digits to include when displaying the parameters? 0 if you don't want to display parameters. Length 1 vector.
0
d <- dst_norm(0.3552, 1.1453) pretty_name(d) pretty_name(d, 2)
Run the code above in your browser using DataLab