prob_left: Find the probability left or right of a number
Description
Probability to the left or right of a number, inclusive or not.
prob_left() is a more general cdf defined using either < or <=, and
prob_right() is a more general survival function defined using either
> or >=.
Usage
prob_left(distribution, of, inclusive)
prob_right(distribution, of, inclusive)
Value
A vector of probabilities.
Arguments
distribution
Distribution to find probabilities of.
of
Find the probability to the left or right of this number.
Could be a vector.
inclusive
Should of be included in the probability calculation?
Logical.