powered by
Makes a finite distribution, which is a distribution with a finite number of possible outcomes.
dst_finite(outcomes, probs)
A distribution with finite outcomes.
Numeric vector representing the potential outcomes of the distribution.
Numeric vector of probabilities corresponding to the outcomes in outcomes. Must not be negative and must sum to 1.
outcomes
dst_empirical()
dst_finite(2:5, probs = 1:4 / 10)
Run the code above in your browser using DataLab