powered by
Makes a Geometric distribution, corresponding to the number of failures in a sequence of independent trials before observing a success.
dst_geom(prob)
A Geometric distribution.
Probability of success in each trial; single numeric between 0 and 1.
d <- dst_geom(0.4) # This version of the Geometric distribution does not count the success. range(d)
Run the code above in your browser using DataLab