Makes a Negative Binomial distribution, corresponding to the number
of failures in a sequence of independent trials until a given number
of successes are observed.
Usage
dst_nbinom(size, prob)
Value
A Negative Binomial distribution.
Arguments
size
Number of successful trials; single positive numeric.
prob
Probability of a successful trial; single numeric
between 0 and 1.