powered by
Representations of the Generalized Extreme Value Distribution
pgev(q, location, scale, shape)qgev(p, location, scale, shape)dgev(x, location, scale, shape)
qgev(p, location, scale, shape)
dgev(x, location, scale, shape)
Vector of evaluated GEV distribution, with length equal to the recycled lengths of q/x/p, location, scale, and shape.
q
x
p
location
scale
shape
Location parameter; numeric vector.
Scale parameter; positive numeric vector.
Shape parameter; numeric vector. This is also the extreme value index, so that shape > 0 is heavy tailed, and shape < 0 is short-tailed.
shape > 0
shape < 0
Vector of probabilities.
Vector of quantiles.
pgev(1:10, 0, 1, 1) dgev(1:10, 1:10, 2, 0) qgev(1:9 / 10, 2, 10, -2)
Run the code above in your browser using DataLab